searchData={"items":[{"type":"task","title":"mix blend.clean","doc":"A task to clean any stale lockfiles and blend build artifacts under the\n`blend/` folder.","ref":"Mix.Tasks.Blend.Clean.html"},{"type":"task","title":"mix blend.get","doc":"A task to resolve your blends and generate lockfiles.\n\nThat is to say, have blend read your defined blends in `blend.exs` and generate\na lockfile for each blend by combining each specific blend overrides with your package\ndependencies in `mix.exs`.","ref":"Mix.Tasks.Blend.Get.html"},{"type":"task","title":"mix blend.init","doc":"A task to generates an empty blend.exs file for you\nto define your blends, if you don't yet have one.\n\nIt is created with a commented example in it.\n\n```\n$ mix blend.init\nSuccessfully created blend.exs file\n```","ref":"Mix.Tasks.Blend.Init.html"},{"type":"task","title":"mix blend.list","doc":"A task to list to quickly get a list of blend names you have defined in\nyour blend.exs file.\n\n```\n$ mix blend.list\nplug_crypto_1\nplug_crypto_2\n```","ref":"Mix.Tasks.Blend.List.html"},{"type":"task","title":"mix blend.premix","doc":"Task to generate the `premix.exs` file, which helps confuguring your\npackage project to easily run any mix task against a specific blend\nlockfile.","ref":"Mix.Tasks.Blend.Premix.html"},{"type":"task","title":"mix blend.update","doc":"A task to update your blend lockfiles dependencies.\n\nThat means, trying to get all the dependencies in each lockfile to their most recent\nversion possible respecting the defined version constraints.","ref":"Mix.Tasks.Blend.Update.html"},{"type":"extras","title":"🥣 Blend","doc":"# 🥣 Blend\n\n[![ci](https://github.com/mimiquate/blend/actions/workflows/ci.yml/badge.svg?branch=main)](https://github.com/mimiquate/blend/actions?query=branch%3Amain)\n[![Hex.pm](https://img.shields.io/hexpm/v/blend.svg)](https://hex.pm/packages/blend)\n[![Docs](https://img.shields.io/badge/docs-gray.svg)](https://hexdocs.pm/blend)\n\nTest your package against different versions of its dependencies.\n\nGenerates and maintains multiple lockfiles based on your defined variations (a.k.a. blends)\nso that you can test your package against different variations of your dependencies versions.","ref":"readme.html"},{"type":"extras","title":"Installation - 🥣 Blend","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `blend` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:blend, \"~> 0.3.0\", only: :dev}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - 🥣 Blend","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"1. Generate `blend.exs` - 🥣 Blend","doc":"```\n$ mix blend.init\n```\n\n#","ref":"readme.html#1-generate-blend-exs"},{"type":"extras","title":"2. Define your blends - 🥣 Blend","doc":"Edit and set your blends in the `blend.exs` file.\n\nFor example, an elixir package that depends on `plug_crypto` with a requirement of `~> 1.2 or ~> 2.0`,\nthat wants to test against the two major versions, would want to define the following:\n\n```elixir\n# blend.exs\n\n# Example for testing against 1.x and 2.x of plug_crypto\n%{\n  plug_crypto_1: [{:plug_crypto, \"~> 1.2\"}],\n  plug_crypto_2: [{:plug_crypto, \"~> 2.0\"}]\n}\n```\n\nin order for blend to generate two different lockfiles that lock `plug_crypto` in each of the\nsupported major versions.\n\nMap keys define the blend name, used for naming the lockfile, and the dependencies list are\nmerged with the package dependencies before resolving and generating the lockfile variation.\n\n#","ref":"readme.html#2-define-your-blends"},{"type":"extras","title":"3. Resolve blends and generate lockfiles - 🥣 Blend","doc":"```\n$ mix blend.get\n```\n\nto resolve your blends and generate new lockfiles with variations of your dependencies under the new `/blend` folder.\n\n```\nblend\n├── _build\n├── deps\n├── plug_crypto_1.mix.lock\n└── plug_crypto_2.mix.lock\n\n```\n\n#","ref":"readme.html#3-resolve-blends-and-generate-lockfiles"},{"type":"extras","title":"4. Ignore blend build artifacts - 🥣 Blend","doc":"```\n# .gitignore\n\n/blend/_build\n/blend/deps\n```\n\nAdd to your `.gitignore` file, before comitting your changes.\n\n\n#","ref":"readme.html#4-ignore-blend-build-artifacts"},{"type":"extras","title":"5. Running in the context of a blend lockfile - 🥣 Blend","doc":"##","ref":"readme.html#5-running-in-the-context-of-a-blend-lockfile"},{"type":"extras","title":"Option A. Overriding your `mix.lock`. - 🥣 Blend","doc":"If you just need a CI job step to run against a blend lockfile, it might be enough to just:\n\n```\n$ cp blend/ .mix.lock mix.lock\n```\n\nNow you can run any task, e.g. run your tests.\n\n```\n$ mix test\n```\n\n##","ref":"readme.html#option-a-overriding-your-mix-lock"},{"type":"extras","title":"Option B. `BLEND` env var configuration - 🥣 Blend","doc":"A more permanent configuration for running mix tasks in the context of a blend lockfile with a simple env var\ncan be acomplished by customizing your `mix.exs` a bit, with the following steps.\n\n###","ref":"readme.html#option-b-blend-env-var-configuration"},{"type":"extras","title":"1. Create a new file `blend/premix.exs` with the following command: - 🥣 Blend","doc":"```\n$ mix blend.premix\n```\n\nThis will generate a `blend/premix.exs` file that needs to be compiled at the top of your `mix.exs` file\nso that some mix env vars are properly set based on the `BLEND` env var before running any mix task.\n\n###","ref":"readme.html#1-create-a-new-file-blend-premix-exs-with-the-following-command"},{"type":"extras","title":"2. Modify your `mix.exs`. - 🥣 Blend","doc":"```elixir\n# mix.exs\n\nCode.compile_file(\"blend/premix.exs\")         # New\n\ndefmodule YourApp.MixProject do\n  ...\n  def project do\n    [\n      ...\n    ]\n    |> Keyword.merge(maybe_lockfile_option()) # New\n  end\n  ....\n\n  defp maybe_lockfile_option do               # New\n    case System.get_env(\"MIX_LOCKFILE\") do    #\n      nil -> []                               #\n      \"\" -> []                                #\n      lockfile -> [lockfile: lockfile]        #\n    end                                       #\n  end                                         #\nend            \n```\n\n###","ref":"readme.html#2-modify-your-mix-exs"},{"type":"extras","title":"3. Enjoy - 🥣 Blend","doc":"Now you can run any task, e.g. run your tests, against different lockfiles locally by just executing:\n\n```\n$ BLEND=  mix test\n```","ref":"readme.html#3-enjoy"},{"type":"extras","title":"Tasks - 🥣 Blend","doc":"```\n$ mix blend.init         # Generate blend.exs\n$ mix blend.get          # Generate blend lockfiles\n$ mix blend.update --all # Update blend lockfiles to latest possible versions\n$ mix blend.list         # List blends\n$ mix blend.clean        # Cleans blends build artifacts and stale lockfiles\n$ mix blend.premix       # Generate premix.exs file\n```","ref":"readme.html#tasks"},{"type":"extras","title":"License - 🥣 Blend","doc":"Copyright 2024 Mimiquate\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license"}],"content_type":"text/markdown"}